@@ -3,10 +3,12 @@
 
 import os
 import re
+import codecs
 from time import time
 
+
 ## Return all the locations from a given file (filePath)
-def read_file(strInfo, filePath):
+def read_file(strInfo, filePath, maxLine=0):
     fileData = {}
     if os.path.exists(filePath):
         p = re.compile(strInfo + '="([^"]+)".*lat="([^"]+)".*lng="([^"]+)".*')
@@ -23,9 +25,16 @@ def read_file(strInfo, filePath):
                         z = q.search(line)
                         if z:
                             zoom = int(z.group(1))
-                        fileData[m.group(1)] = (float(m.group(2)),
+                        if m.group(1) in fileData:
+                            name = '%s %i' % (m.group(1), len(fileData))
+                        else:
+                            name = m.group(1)
+                        fileData[name] = (float(m.group(2)),
                                                 float(m.group(3)),
                                                 zoom)
+                if (maxLine > 0):
+                    if (len(fileData) > maxLine):
+                        break
             except:
                 pass
         file.close()
@@ -34,6 +43,7 @@ def read_file(strInfo, filePath):
         write_file(strInfo, filePath, fileData)
         return None
 
+
 ## Writes all the locations (fileData) to given file (filePath)
 def write_file(strInfo, filePath, fileData):
     try:
@@ -43,26 +53,28 @@ def write_file(strInfo, filePath, fileData):
         print '  ' + filePath
         return
 
-    file.write("# This is the "+ strInfo +"s file used by GMapCatcher.\n"+\
-        "#\n"+\
-        "# This file contains a list of Locations/Position.\n"+\
-        "# Each entry should be kept on an individual line.\n"+\
-        "# The latitude, longitud and zoom should be TAB separated.\n"+\
-        "#\n"+\
-        "# Additionally, comments (such as these) may be inserted on\n"+\
-        "# lines sarting with a '#' symbol.\n"+\
+    file.write(codecs.BOM_UTF8+"# This is the " + strInfo + "s file used by GMapCatcher.\n" +
+        "#\n" +
+        "# This file contains a list of Locations/Position.\n" +
+        "# Each entry should be kept on an individual line,\n" +
+        "# and MUST have a unique name.\n" +
+        "# The latitude, longitud and zoom should be TAB separated.\n" +
+        "#\n" +
+        "# Additionally, comments (such as these) may be inserted on\n" +
+        "# lines sarting with a '#' symbol.\n" +
         "#\n" + "# For example:\n" + "#\n" +
-        ('#   '+ strInfo +'="%s"\tlat="%f"\tlng="%f"\tzoom="%i"\n' %
-         ("Paris, France", 48.856667, 2.350987, 5)) + "#\n" )
+        ('#   ' + strInfo + '="%s"\tlat="%f"\tlng="%f"\tzoom="%i"\n' %
+         ("Paris, France", 48.856667, 2.350987, 5)) + "#\n")
 
     for l in sorted(fileData.keys()):
-    	# The method 'write' takes an unicode string here and acording to python manual
-    	# it translates it automatically to string buffer acording to system defaults.
-    	# Probably all systems translate unicode to UTF-8
+        # The method 'write' takes an unicode string here and acording to python manual
+        # it translates it automatically to string buffer acording to system defaults.
+        # Probably all systems translate unicode to UTF-8
         file.write(strInfo + '="%s"\tlat="%f"\tlng="%f"\tzoom="%i"\n' %
-                  (l, fileData[l][0], fileData[l][1], fileData[l][2]))
+                  (l.encode('UTF-8'), fileData[l][0], fileData[l][1], fileData[l][2]))
     file.close()
 
+
 ## Append the location (strData) to given file (filePath)
 def append_file(strInfo, filePath, strData, strName, extraTag=False):
     try:
@@ -73,12 +85,13 @@ def append_file(strInfo, filePath, strData, strName, extraTag=False):
         return
     if extraTag:
         file.write(strInfo + '="%s"\tlat="%s"\tlng="%s"\tzoom="%i"\t%s\n' %
-                  (strName, strData[0], strData[1], strData[2]+2, extraTag))
+                  (strName, strData[0], strData[1], strData[2] + 2, extraTag))
     else:
         file.write(strInfo + '="%s"\tlat="%s"\tlng="%s"\tzoom="%i"\n' %
-                  (strName, strData[0], strData[1], strData[2]+2))
+                  (strName, strData[0], strData[1], strData[2] + 2))
     file.close()
 
+
 ## Writes a new gtkrc file with the given theme
 def write_gtkrc(strTheme):
     filePath = './etc/gtk-2.0/gtkrc'
@@ -89,14 +102,15 @@ def write_gtkrc(strTheme):
         print '  ' + filePath
         return
 
-    file.write('# You can change the GMapCatcher theme here!\n'+\
-               '#\n'+\
-               '#gtk-theme-name = "Industrial"\n'+\
-               '#gtk-theme-name = "XFCE-4.2"\n'+\
-               '\n'+\
+    file.write('# You can change the GMapCatcher theme here!\n' +
+               '#\n' +
+               '#gtk-theme-name = "Industrial"\n' +
+               '#gtk-theme-name = "XFCE-4.2"\n' +
+               '\n' +
                'gtk-theme-name = "' + strTheme + '"')
     file.close()
 
+
 ## Returns the current theme from the gtkrc file
 def read_gtkrc():
     filePath = './etc/gtk-2.0/gtkrc'
@@ -107,6 +121,7 @@ def read_gtkrc():
             if line.startswith('gtk-theme-name'):
                 return line[17:].strip('"')
 
+
 ## Returns all the available themes
 def get_themes():
     themesPath = './share/themes/'
@@ -117,18 +132,20 @@ def get_themes():
                 myThemes += [l]
     return myThemes
 
+
 ## Checks if a directory exist if not it will be created
 def check_dir(strPath, strSubPath=None):
     if (strSubPath is not None):
         strPath = os.path.join(strPath, strSubPath)
     if not os.path.isdir(strPath):
         try:
-            os.mkdir(strPath)
+            os.makedirs(strPath)
         except Exception:
             print 'Error! Can not create directory:'
             print '  ' + strPath
     return strPath
 
+
 ## Deletes a given file
 def del_file(filename):
     try:
@@ -136,6 +153,7 @@ def del_file(filename):
     except:
         pass
 
+
 ## Check if the file is older than given time
 #  (24h * 3600s/h) = 86400s
 def is_old(filename, intDays):
@@ -144,6 +162,7 @@ def is_old(filename, intDays):
             return True
     return False
 
+
 ## Remove file if is older than given time
 def delete_old(filename, intDays):
     if is_old(filename, intDays):
