@@ -3,6 +3,7 @@
 
 from mapConst import *
 
+
 class MapArgs():
     max_zl = MAP_MAX_ZOOM_LEVEL
     min_zl = MAP_MIN_ZOOM_LEVEL + 4
@@ -12,9 +13,10 @@ class MapArgs():
     lat = None
     lng = None
     location = None
+    gpx = None
     layer = LAYER_MAP
-    width = 0
-    height = 0
+    width = -1
+    height = -1
 
     def print_help(self):
         print ' '
@@ -24,6 +26,7 @@ class MapArgs():
         print '  --location=   location to download'
         print '  --latitude=   Latitude of the location '
         print '  --longitude=  Longitude of the location'
+        print '  --gpx=        GPX file with a path'
         print ' '
         print '  --map         Retrieve map images (default)'
         print '  --satellite   Retrieve satellite images'
@@ -32,8 +35,9 @@ class MapArgs():
         print ' '
         print '  --latrange=   Latitude Range to get    (default = %f)' % self.lat_range
         print '  --lngrange=   Longitude Range to get   (default = %f)' % self.lng_range
-        print '  --height=     Height in Km (will override latrange)'  
-        print '  --width=      Width in Km (will override lngrange)'   
+        print '  --height=     Height in Km (will override latrange)'
+        print '  --width=      Width in Km (will override lngrange) for locations,'
+        print '                and width in "tiles" for GPX paths.'
         print ' '
         print '  --max-zoom=   Maximum Zoom   (default = %d)' % self.max_zl
         print '  --min-zoom=   Minimum Zoom   (default = %d)' % self.min_zl
@@ -45,11 +49,13 @@ class MapArgs():
         print '  mapdownloader --location="Paris, France"'
         print '  mapdownloader --min-zoom=13 --full-range'
         print '  mapdownloader --latitude=37.979180 --longitude=23.716647'
+        print '  mapdownloader --gpx=myfile.gpx --width=2'
 
     def __init__(self, arrArgs=()):
         if len(arrArgs) > 1:
             for arg in arrArgs[1:]:
                 if arg.startswith('--'):
+                    oarg = arg  # Argument with the original case
                     arg = arg.lower()
                     if arg.startswith('--max-zoom-level='):
                         self.max_zl = int(arg[17:])
@@ -65,6 +71,8 @@ class MapArgs():
                         self.lng = float(arg[12:])
                     elif arg.startswith('--latitude='):
                         self.lat = float(arg[11:])
+                    elif arg.startswith('--gpx='):
+                        self.gpx = oarg[6:]
                     elif arg.startswith('--latrange='):
                         self.lat_range = float(arg[11:])
                     elif arg.startswith('--lngrange='):
@@ -81,6 +89,8 @@ class MapArgs():
                         self.layer = LAYER_TER
                     elif arg.startswith('--hybrid'):
                         self.layer = LAYER_HYB
+                    elif arg.startswith('--mapid='):
+                        self.layer = arg[8:]
                     elif arg.startswith('--full-range'):
                         self.location = "Whole World"
                         self.lng = 0
@@ -89,9 +99,9 @@ class MapArgs():
                         self.lng_range = 179
 
     def __str__(self):
-        return ("mapdownloader --max-zoom=%s --min-zoom=%s" \
-                + " --latitude=%s --longitude=%s" \
-                + " --width=%s --height=%s") % \
+        return ("mapdownload --max-zoom=%s --min-zoom=%s" +
+                " --latitude=%s --longitude=%s" +
+                " --width=%s --height=%s") % \
                (self.max_zl, self.min_zl,
                 self.lat, self.lng,
                 self.width, self.height)
