@@ -3,9 +3,10 @@
 
 import os
 import fileUtils
-import mapPixbuf
+import widgets.mapPixbuf as mapPixbuf
 from mapConst import *
 
+
 class MyMarkers:
     # coord = (lat, lng, zoom_level)
     positions = {}
@@ -42,13 +43,13 @@ class MyMarkers:
 
     def get_pixDim(self, zl):
         maxZoom = MAP_MAX_ZOOM_LEVEL - 2
-        if zl >= maxZoom :
+        if zl >= maxZoom:
             return 56
         elif zl <= 1:
             return 256
         else:
             return 56 + int((maxZoom - zl) * 15)
 
-    def get_marker_pixbuf(self, zl, image='marker.png'):
+    def get_marker_pixbuf(self, zl, image='marker_s.png'):
         pixDim = self.get_pixDim(zl)
         return mapPixbuf.getImage(image, pixDim, pixDim)
