@@ -3,6 +3,7 @@
 
 from gmapcatcher.mapConst import MAP_MAX_ZOOM_LEVEL, LAYER_MAP, LAYER_SAT, LAYER_HYB
 
+
 ## Returns a template URL for the Yahoo mas
 def layer_url_template(layer):
     if layer == LAYER_MAP:
@@ -12,8 +13,9 @@ def layer_url_template(layer):
     elif layer == LAYER_HYB:
         return 'http://maps.yimg.com/hx/tl?v=9&t=h&imgtype=png&s=256&x=%i&y=%i&z=%i'
 
+
 ## Returns the URL to the Yahoo map tile
-def get_url(counter, coord, layer):
+def get_url(counter, coord, layer, conf):
     #server = ['a', 'b', 'c']
     return layer_url_template(layer) % (
             coord[0],
