@@ -1,16 +1,13 @@
 ## @package gmapcatcher.mapUpdate
 # All the update related logic
 
-import os
 from mapConst import *
-if IS_GTK:
-    import gtk
-    from customMsgBox import updateMsgBox
+import gtk
+from widgets.customMsgBox import updateMsgBox
 import openanything
 from threading import Timer
 
 
-
 ## Class used to get latest version info
 class MapUpdate():
     def __init__(self, strURL):
@@ -27,7 +24,7 @@ class MapUpdate():
     def get_data(self, strURL):
         try:
             oa = openanything.fetch(strURL)
-            if oa['status']==200:
+            if oa['status'] == 200:
                 return oa['data']
         except Exception:
             return False
@@ -51,17 +48,16 @@ class CheckForUpdates():
         self.myThread.cancel()
         if self.update:
             if self.update.latest_version > VERSION:
-                if IS_GTK:
-                    updateMsgBox(
-                            "Update detected! \n" +
-                            ("A new version of %s is available \n\n" % NAME) +
-                            ("Your version is %s \n" % VERSION ) +
-                            ("Current version is %s" % 
-                            self.update.latest_version),
-                            WEB_ADDRESS,
-                            self.update.latest_installer
-                    )
-                    gtk.main()
+                updateMsgBox(
+                        "Update detected! \n" +
+                        ("A new version of %s is available \n\n" % NAME) +
+                        ("Your version is %s \n" % VERSION) +
+                        ("Current version is %s" %
+                        self.update.latest_version),
+                        WEB_ADDRESS,
+                        self.update.latest_installer
+                )
+                gtk.main()
 
 if __name__ == "__main__":
     # Test some URLs
