@@ -1,7 +1,7 @@
 from __future__ import with_statement
-from mapUtils import altitude_to_zoom
 from mapServers.googleMaps import search_location
 
+
 def kml_to_markers(strFileName, marker, lookup=False):
     from xml.dom.minidom import parseString
 
@@ -39,3 +39,27 @@ def kml_to_markers(strFileName, marker, lookup=False):
                 marker.refresh()
     dom.unlink()
 
+
+def load_gpx_coords(gpxfile):
+    from xml.dom.minidom import parseString
+
+    try:
+        with open(gpxfile) as f:
+            fileString = unicode(f.read(), errors='ignore')
+        dom = parseString(fileString)
+        trkpt = dom.getElementsByTagName("trkpt")
+    except:
+        raise
+
+    coords = []
+    for element in trkpt:
+        try:
+            elem_lat = float(element.getAttribute('lat'))
+            elem_lon = float(element.getAttribute('lon'))
+        except:
+            pass
+        else:
+            coords.append((elem_lat, elem_lon))
+    dom.unlink()
+
+    return coords
